#
# spec file for package xplayer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     zeitgeist
Name:           xplayer
Version:        2.4.4
Release:        4.1
Summary:        Generic media player
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/linuxmint/xplayer
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM return no value in void function
Patch0:         xplayer-2.2.1-return-no-value-in-void-function.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gstreamer-plugins-good >= 0.11.93
# For gst-inspect tool
BuildRequires:  gstreamer-utils >= 0.11.93
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  python3-pylint
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.14.1
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(%{name}-plparser)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(clutter-1.0) >= 1.10.0
BuildRequires:  pkgconfig(clutter-gst-3.0) >= 2.99.2
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.0.2
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.82
BuildRequires:  pkgconfig(glib-2.0) >= 2.33.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(grilo-0.3)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 0.11.93
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= 1.0.2
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 0.11.93
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.1.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:  pkgconfig(lirc)
BuildRequires:  pkgconfig(pygobject-3.0) >= 2.90.3
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xapp)
BuildRequires:  pkgconfig(xkbfile)
%if %{with zeitgeist}
BuildRequires:  pkgconfig(zeitgeist-2.0) >= 0.9.12
%else
Obsoletes:      %{name}-plugin-zeitgeist <= %{version}
%endif
Requires:       gstreamer-plugin-cluttergst3
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       iso-codes
Requires:       python3-gobject-Gdk
Recommends:     %{name}-plugins
Suggests:       gnome-dvb-daemon
Obsoletes:      %{name}-browser-plugin < %{version}
Obsoletes:      %{name}-browser-plugin-gmp < %{version}
Obsoletes:      %{name}-browser-plugin-vegas < %{version}

%description
xplayer is a media player based on GStreamer for the Cinnamon
desktop and others. It features a playlist, a full-screen mode,
seek and volume controls, and complete keyboard navigation.

%package plugins
Summary:        Plugins for xplayer media player
Requires:       %{name} = %{version}
Recommends:     brasero
Recommends:     python3-beautifulsoup4
Recommends:     python3-httplib2
Suggests:       gromit

%description plugins
xplayer is a media player based on GStreamer for the Cinnamon
desktop and others. It features a playlist, a full-screen mode,
seek and volume controls, and complete keyboard navigation.

This package includes plugins for xplayer, to add advanced features.

%if %{with zeitgeist}
%package plugin-zeitgeist
Summary:        Plugins for xplayer media player -- Zeitgeist Support
Requires:       %{name} = %{version}

%description plugin-zeitgeist
xplayer is a media player based on GStreamer for the Cinnamon
desktop and others. It features a playlist, a full-screen mode,
seek and volume controls, and complete keyboard navigation.

This package includes the Zeitgeist plugin for xplayer.
%endif

%package devel
Summary:        Development files for xplayer media player
Requires:       %{name} = %{version}

%description devel
xplayer is a media player based on GStreamer for the Cinnamon
desktop and others. It features a playlist, a full-screen mode,
seek and volume controls, and complete keyboard navigation.

This package contains files for development.

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static \
  --disable-Werror
%make_build

%install
%make_install
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

# delete .la file
rm -f %{buildroot}%{_libdir}/lib%{name}.la

%post
%ldconfig

%postun
%ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}*
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/org.x.player.enums.xml
%{_datadir}/glib-2.0/schemas/org.x.player.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{name}*.*
%{_datadir}/icons/hicolor/*/devices/%{name}*.*
%{_datadir}/icons/hicolor/*/actions/%{name}*.*
%dir %{_datadir}/thumbnailers/
%{_datadir}/thumbnailers/%{name}.thumbnailer
%{_datadir}/%{name}/
%{_mandir}/man?/%{name}*.?%{?ext_man}
# Own directories for plugins.
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/plugins/
# Be careful here: libdir contains plugins while libexecdir
# contains a small utility for the main package.
%if "%{_libdir}" != "%{_libexecdir}"
%dir %{_libexecdir}/%{name}/
%endif
%{_libexecdir}/%{name}/%{name}-bugreport.py
%{_libdir}/lib%{name}.so.*
%{_libdir}/girepository-1.0/Xplayer-1.0.typelib
%{_datadir}/help/C/%{name}

%files lang -f %{name}.lang

%files plugins
%{_libdir}/%{name}/plugins/apple-trailers/
%{_libdir}/%{name}/plugins/autoload-subtitles/
%{_libdir}/%{name}/plugins/brasero-disc-recorder/
%{_libdir}/%{name}/plugins/chapters/
%{_libdir}/%{name}/plugins/dbus/
%{_libdir}/%{name}/plugins/grilo/
%{_libdir}/%{name}/plugins/gromit/
%{_libdir}/%{name}/plugins/im-status/
%{_libdir}/%{name}/plugins/lirc/
%{_libdir}/%{name}/plugins/media-player-keys/
%{_libdir}/%{name}/plugins/ontop/
%{_libdir}/%{name}/plugins/opensubtitles/
%{_libdir}/%{name}/plugins/properties/
%{_libdir}/%{name}/plugins/pythonconsole/
%{_libdir}/%{name}/plugins/recent/
%{_libdir}/%{name}/plugins/rotation/
%{_libdir}/%{name}/plugins/screensaver/
%{_libdir}/%{name}/plugins/screenshot/
%{_libdir}/%{name}/plugins/skipto/
%{_libdir}/%{name}/plugins/vimeo/
%{_datadir}/glib-2.0/schemas/org.x.player.plugins.opensubtitles.gschema.xml
%{_datadir}/glib-2.0/schemas/org.x.player.plugins.pythonconsole.gschema.xml

%if %{with zeitgeist}
%files plugin-zeitgeist
%{_libdir}/%{name}/plugins/zeitgeist-dp/
%endif

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/gir-1.0/*.gir

%changelog
* Mon Aug 12 2024 Richard Rahl <rrahl0@opensuse.org>
- remove older Leap releases support
- switch some dependencies to pkgconfig
- adapt the spec file to other Cinnamon packages, as the Xapps get soon
  an overhaul from upstream with more packages getting added
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Oct 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(libepc-ui-1.0) BuildRequires.
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.4:
  * l10n: Update translations
* Tue Jan 25 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 2.4.2.
  * l10n: Update translations
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Mar  6 2021 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 2.4.0.
  * Packaging: Move thumbnailer and audio-preview to a new package
* Mon Dec  7 2020 andy great <andythe_great@pm.me>
- Update to version 2.2.8.
  * Bump version with no change.
- Updates for 2.2.7.
  * l10n: Update translations
* Tue Sep 29 2020 andy great <andythe_great@pm.me>
- Update to version 2.2.6.
  * Packaging: Remove obsolete calls to dh_python2
  * l10n: Update translations
- Update since version 2.2.1.
  * Packaging: Remove python build-dep
  * debian: Move the .thumbnailer launcher file to the same package
    that contains the thumbnail executable.
* Fri Sep 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Change define bcond_without zeitgeist to becond_with, no longer
  build zeitgeist support, as it is slated for removal from distro.
* Wed Jan 15 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to Python3. Replace python-devel with python3-base
  BuildRequires and libpeas-loader-python, python-beautifulsoup,
  python2-httplib2 and python-httplib2 with libpeas-loader-python3
  Requires and python3-beautifulsoup4 and python3-httplib2
  Recommends. Add python3-pylint, needed for python support to be
  actually enabled, and pass export PYTHON=%%%%{_bindir}/python3.
  Drop python-gobject, python2-gobject-Gdk,
  gstreamer-plugin-gstclutter-3_0, python-gobject-Gdk and the
  conditonals around these. Add python3-gobject-Gdk, it is the only
  one needed.
* Tue Aug 13 2019 Marguerite Su <i@marguerite.su>
- add xplayer-2.2.1-return-no-value-in-void-function.patch
* Sun Jul 28 2019 Marguerite Su <i@marguerite.su>
- Update to version 2.2.1:
  * Update translations
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.0:
  * check for bvw->priv->tagcache == NULL in bacon-video-widget.c update_orientation_from_video (#150)
  * Add Ctrl+W shortcut to close the app
  * l10n: Update translations
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 2.0.2:
  * Close the va_list 'ap' with va_end (#140)
  * l10n: Update translations
  * Port to python3 (#104)
  * grilo plugin: Move derived widgets from GtkBuilder (#119)
  * Add croatian manual (#105)
  * Packaging: Update dependencies
  * CI: Remove Mint 18
  * Packaging: Update dependencies
  * Rename dbusservice plugin to MPRIS.
  * Fix python console plugin
  * l10n: Update POT
  * Consistent icon usage in all xapps: help-contents (#133)
  * pythonconsole: Import all classes to expose publicly (#123)
  * thumbnailer: Use g_clear_object (#124)
  * thumbnailer: Simplify getting the file's basename (#125)
  * thumbnailer: Fix memory leak (#129)
  * gst: Fix GstMemory memory leak (#131)
  * gst: Add new flags for playbin (#130)
  * dbusservice: Force Position to be int64 (#132)
  * thumbnailer: Remove film strip from generated thumbnails (#126)
  * missing plugins: Pass in Xplayer's desktop file ID
  * missing plugins: Break out a function
  * missing plugins: Ask the user before spawning a plugin search
  * core: Add missing enum members to switch statements
  * core: Conditionalise use of new GStreamer GST_MESSAGE_* API
  * backend: Fix incorrect return type
  * Bump gstreamer version to 1.6.0
  * thumbnailer: Also blacklist new vaapidecodebin
  * thumbnailer: blacklist new vaapi plugin names
  * thumbnailer: Blacklist the bmcdec plugin
  * thumbnailer: Blacklist GStreamer plugins rather than features
  * thumbnailer: Blacklist video4linux2 plugin
  * src/plugins/dbusservice/dbusservice.py: Fix dbus/mpris next and previous commands.
  * Play/pause with SPACE instead of CTRL+SPACE (#98) (#137)
- Remove xplayer-fix-grilo.patch merged upstream.
* Mon Sep 10 2018 sor.alexei@meowr.ru
- Add xplayer-fix-grilo.patch: Fix start-up issues caused by the
  Grilo plugin (boo#1106676).
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.3 (changes since 1.8.1):
  * Fix "Fit window to movie".
  * Update translations.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.1:
  * Update translations.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.8.0:
  * Do not use gnome-common.
  * Fix the python shebang.
  * Clean up the auto-generated files.
  * Fix a compilation error.
  * Fix "Pause" handler for the MPRIS interface, as well as the
    media key interface. The media-key handler simply hadn't
    implemented it, and the mpris plugin (python) was encountering
    an introspection namespace issue with the pause methods.
  * rotation plugin: Fix build, remove generated files, and allow
    the build to compile the .vala source.
* Thu Mar 15 2018 sor.alexei@meowr.ru
- Require gstreamer-plugin-cluttergst3 instead of
  gstreamer-plugin-gstclutter-3_0 on Leap 15.0 or later.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.1:
  * Update translations.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.6.0:
  * Menubar: Renamed Movie menu to File.
  * Remove xplayer-mozilla.
  * Fullscreen: Improve layout.
  * Fullscreen: Invert button layout.
  * Fullscreen: Remove top button box and integrate buttons into
    statusbar.
  * Fullscreen: Increase statusbar border width to make
    GtkVolumeButton pop up visible.
  * Update translations.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.4.3:
  * Update translations.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * xplayer-screenshot-plugin: Fix -Werror=format-nonliteral.
  * xplayer-playlist.c: Fix void-return in a non-void function.
  * Update translations.
- Remove xplayer-void-return-no-return.patch: merged upstream.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.1 (changes since 1.2.2):
  * Add an option to use the dark theme variant (overriding current
    system theme). The default behaviour is to use the dark theme
    unless this new option is disabled (gh#linuxmint#xplayer#38).
  * Add an option to display or hide subtitles.
  * Subtitles: Reduce default font size from 20 to 18.
  * Subtitles: Autoload srt files by default.
  * Preferences: Reorganize layout for subtitle options.
  * Revamp language/subtitle selection.
  * Revamp the OSD.
  * Subtitles/Languages: Fix showing the track name when it doesn't
    correspond to a known language.
  * Add the ability to change the playback speed.
  * OSD: Show track position/length when seeking.
  * Remove support for visualisations.
  * Help: Update man page and help.
  * Focus window when a new file is opened.
  * ui: Move the seek slider inline with the play controls.
  * controls: Move the fullscreen button to the right of the seek
    bar.
  * player-controls: Rearrange and resize the items a bit.
  * player-controls: Actually show the time/seek label on the new
    controls.
  * ui: Remove the statusbar.
  * sidebar: Tweak the styling of the sidebar toolbar a bit.
  * Fix Previous button sensitivity/role.
  * Don't show OSD in fullscreen.
  * l10n: The Update POT file.
  * Update translations
- Require on xplayer-plugins.
- Add xplayer-void-return-no-return.patch.
* Thu Apr  6 2017 sor.alexei@meowr.ru
- Use Gtk3 clutter-gst unconditionally.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Don't show OSD in fullscreen.
  * Update translations.
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Fix detection of valac.
  * Fix warnings.
  * Update translations.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Convert most of the icons to symbolics.
  * Don't show sidebar by default.
  * Fullscreen: Add a screen blanking button.
  * Fix missing seek bar in fullscreen mode.
  * Enable rotation and opensubtitles plugins by default.
  * Explicity use python 2.
  * thumbnailer: Add support for rotated thumbnails.
  * backend: Automatically rotate mobile phone videos.
  * backend: Remove use of obsolete clutter function.
  * Change name from Videos to Media Player.
  * backend: Don't warn when rotation is unset.
  * dbus: Show media name when no metadata is available.
  * Enable dbus plugin by default.
* Sat Jul 23 2016 dimstar@opensuse.org
- Also use grilo-0.3 on openSUSE Leap 42.2+.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.7:
  * Fix screensaver inhibit on audio playback.
  * Update translations.
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Recolour the xplayer-view-sidebar-symbolic.svg for it to use
    standard symbolic icon colouring.
  * Add missing credits to the Totem developers in the AUTHORS file.
  * Show application name in about dialog.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 1.0.5:
  * Update translations.
* Tue May 17 2016 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Add missing libpeas-loader-python requirement for D-Bus plugin.
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.3:
  * Improve scroll seeking in shorter videos/music.
  * Fix not scrolling backwards.
  * Add support for Grilo 0.3.x.
  * Update translations.
- Add dependencies for Python plugins.
* Wed Feb 10 2016 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Don't capitalise in the dconf schema path.
* Sun Feb  7 2016 sor.alexei@meowr.ru
- Initial package, based on totem's package.
